@@ -2,11 +2,11 @@
 
 """
 This file is part of Pondus, a personal weight manager.
-Copyright (C) 2007-10  Eike Nicklas <eike@ephys.de>
+Copyright (C) 2007-11  Eike Nicklas <eike@ephys.de>
 
 This program is free software licensed under the MIT license. For details
 see LICENSE or http://www.opensource.org/licenses/mit-license.php
 """
 
-__all__ = ['core', 'gui']
-__version__ = '0.7.2'
+__all__ = ['backends', 'core', 'gui']
+__version__ = '0.8.0'
