@@ -2,12 +2,12 @@
 
 """
 This file is part of Pondus, a personal weight manager.
-Copyright (C) 2007-10  Eike Nicklas <eike@ephys.de>
+Copyright (C) 2007-11  Eike Nicklas <eike@ephys.de>
 
 This program is free software licensed under the MIT license. For details
 see LICENSE or http://www.opensource.org/licenses/mit-license.php
 """
 
-__all__ = ['all_datasets', 'config_parser', 'csv_parser', 'dataset',
-           'filelock', 'initialize', 'option_parser', 'parameters',
-           'person', 'plot', 'util']
+__all__ = ['all_datasets', 'config_parser', 'dataset', 'filelock',
+            'initialize', 'logger', 'option_parser', 'parameters',
+            'person', 'plot', 'util']
