@@ -2,24 +2,30 @@
 
 """
 This file is part of Pondus, a personal weight manager.
-Copyright (C) 2007-10  Eike Nicklas <eike@ephys.de>
+Copyright (C) 2007-11  Eike Nicklas <eike@ephys.de>
 
 This program is free software licensed under the MIT license. For details
 see LICENSE or http://www.opensource.org/licenses/mit-license.php
 """
 
+
 class Dataset(object):
     """Implements the structure of single weight measurements."""
 
-    def __init__(self, id_, date, weight):
+    def __init__(self, id_, date, weight, bodyfat=None, muscle=None,
+            water=None, note=None):
         """Creates a new dataset with the given values.
 
         Weight is always in kg. Weight has one digit precision when using
         metric units and two digits precision when using imperial units to
         ensure proper conversion to lbs."""
-        self.id =  id_
+        self.id = id_
         self.date = date
         self.weight = weight
+        self.bodyfat = bodyfat
+        self.muscle = muscle
+        self.water = water
+        self.note = note
 
     def _get_weight_lbs(self):
         """Converts from kg to lbs and returns weight in lbs."""
