@@ -28,6 +28,10 @@ config_default = {'window.remember_size': False,
                   'window.height': 300,
                   'preferences.unit_system': 'metric',
                   'preferences.use_calendar': False,
+                  'preferences.use_bodyfat': False,
+                  'preferences.use_muscle': False,
+                  'preferences.use_water': False,
+                  'preferences.use_note': False,
                   'preferences.use_weight_plan': False}
 config = dict(config_default)
 have_mpl = False
@@ -35,7 +39,7 @@ convert_weight_data_to_kg = False
 
 # tags used in the xml file and dataset objects
 keys_required = ('id', 'date', 'weight')
-keys_optional = ()
+keys_optional = ('bodyfat', 'muscle', 'water', 'note')
 
 # paths to button/logo icons used
 plot_button_path = '/usr/share/pondus/plot.png'
