@@ -2,15 +2,19 @@
 
 """
 This file is part of Pondus, a personal weight manager.
-Copyright (C) 2008-10  Eike Nicklas <eike@ephys.de>
+Copyright (C) 2008-11  Eike Nicklas <eike@ephys.de>
 
 This program is free software licensed under the MIT license. For details
 see LICENSE or http://www.opensource.org/licenses/mit-license.php
 """
 
+import pygtk
+pygtk.require('2.0')
+
 import gtk
 import os
 
+
 class SelectFileDialog(object):
     """Allows the user to select a file."""
 
