@@ -2,18 +2,22 @@
 
 """
 This file is part of Pondus, a personal weight manager.
-Copyright (C) 2007-10  Eike Nicklas <eike@ephys.de>
+Copyright (C) 2007-11  Eike Nicklas <eike@ephys.de>
 
 This program is free software licensed under the MIT license. For details
 see LICENSE or http://www.opensource.org/licenses/mit-license.php
 """
 
+import pygtk
+pygtk.require('2.0')
+
 import gtk
 import os
 import threading
 
 from pondus.core import parameters
 from pondus.core import initialize
+from pondus.core.logger import logger
 from pondus.gui import guiutil
 from pondus.gui.dialog_add import AddDataDialog
 from pondus.gui.dialog_message import MessageDialog
@@ -113,7 +117,7 @@ class MainWindow(object):
         datawindow = gtk.ScrolledWindow()
         datawindow.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
         datawindow.set_shadow_type(gtk.SHADOW_IN)
-        self.datalist = gtk.ListStore(int, str, str)
+        self.datalist = gtk.ListStore(int, str, str, str)
         self.display_data(self.datasetdata)
         self.dataview = gtk.TreeView(self.datalist)
         self.add_column(_('Date'), 1)
@@ -121,6 +125,7 @@ class MainWindow(object):
         self.datalist.set_sort_func(2, guiutil.sort_function_weight, None)
         self.datalist.set_sort_column_id(1, gtk.SORT_DESCENDING)
         self.dataview.set_rules_hint(True)
+        self.dataview.set_tooltip_column(3)
         datawindow.add(self.dataview)
         self.contentbox.pack_start(datawindow)
 
@@ -150,9 +155,7 @@ class MainWindow(object):
         # display window with content
         self.window.show_all()
 
-
     # callback functions
-
     def destroy(self, widget, data=None):
         """Quits the application cleanly."""
         if parameters.config['window.remember_size']:
@@ -166,7 +169,8 @@ class MainWindow(object):
     def add_dialog(self, widget):
         """Runs the dialog to add a new dataset and then adds it to
         self.datasetdata and self.datalist."""
-        dialog = AddDataDialog(self.datasetdata.get_new_dataset(), edit=False)
+        dialog = AddDataDialog(self.window,
+                            self.datasetdata.get_new_dataset(), edit=False)
         newdata = dialog.run()
         if newdata is not None:
             self.datasetdata.add(newdata)
@@ -195,9 +199,9 @@ class MainWindow(object):
             if self.datalist.iter_is_valid(treeiter):
                 self.treeselection.select_iter(treeiter)
             else:
-                lastpath = len(self.datalist)-1
+                lastpath = len(self.datalist) - 1
                 if lastpath >= 0:
-                    self.treeselection.select_path(len(self.datalist)-1)
+                    self.treeselection.select_path(len(self.datalist) - 1)
                 else:
                     self.set_selection_active(self.treeselection)
                     self.set_plot_action_active()
@@ -207,7 +211,8 @@ class MainWindow(object):
         to self.datasetdata and self.datalist."""
         (listmodel, treeiter) = self.treeselection.get_selected()
         id_selected = listmodel.get_value(treeiter, 0)
-        dialog = AddDataDialog(self.datasetdata.get(id_selected), edit=True)
+        dialog = AddDataDialog(self.window,
+                            self.datasetdata.get(id_selected), edit=True)
         newdata = dialog.run()
         if newdata is not None:
             self.datasetdata.add(newdata)
@@ -217,7 +222,8 @@ class MainWindow(object):
                 new_weight = round(newdata.weight, 1)
             self.datalist.set(treeiter,
                 1, str(newdata.date),
-                2, str(new_weight))
+                2, str(new_weight),
+                3, guiutil.get_tooltip(newdata))
 
     def plot_dialog(self, widget):
         """Runs the plotting dialog."""
@@ -282,9 +288,7 @@ class MainWindow(object):
             self.removeaction.set_sensitive(True)
             self.editaction.set_sensitive(True)
 
-
     # helper methods
-
     def set_plot_action_active(self):
         """Tests, whether a dataset exists and matplotlib is available
         and sets sensitivity of the plot action accordingly."""
@@ -308,12 +312,12 @@ class MainWindow(object):
             self.contentbox.remove(self.modeselector)
         self.contentbox.show_all()
 
-    def add_column(self, title, columnId):
+    def add_column(self, title, column_id):
         """Adds a column to the list view: First, create the
         gtk.TreeViewColumn and then set some needed properties."""
         column = gtk.TreeViewColumn(
-                            title, gtk.CellRendererText(), text=columnId)
-        column.set_sort_column_id(columnId)
+                            title, gtk.CellRendererText(), text=column_id)
+        column.set_sort_column_id(column_id)
         self.dataview.append_column(column)
 
     def display_data(self, datasetdata):
@@ -325,12 +329,13 @@ class MainWindow(object):
     def append_dataset(self, dataset):
         """Appends a dataset to the list model."""
         if parameters.config['preferences.unit_system'] == 'imperial':
-            dataset_list = [dataset.id, dataset.date, dataset.weight_lbs]
+            weight = dataset.weight_lbs
         else:
-            dataset_list = [dataset.id, dataset.date, round(dataset.weight, 1)]
+            weight = round(dataset.weight, 1)
+        dataset_list = [dataset.id, dataset.date, weight, \
+                guiutil.get_tooltip(dataset)]
         return self.datalist.append(dataset_list)
 
-
     # main function
     def main(self):
         """Starts the gtk main loop."""
@@ -359,7 +364,8 @@ def import_mpl():
     try:
         from matplotlib import dates
     except ImportError:
-        print _('Note: python-matplotlib is not installed, plotting disabled!')
+        logger.warning( \
+            _('python-matplotlib is not installed, plotting disabled!'))
     else:
         parameters.have_mpl = True
         # speed up opening of plot dialog by importing it here
